searchData={"items":[{"type":"module","title":"FrancisHtmx","doc":"Provides a macro to render htmx content by loading htmx.js.\nAlso provides a sigil to render EEx content similar to ~H from Phoenix.LiveView\n\nUsage:\n```elixir\n  defmodule Example do\n    use Francis\n    import FrancisHtmx\n\n    htmx(fn _conn ->\n      assigns = %{}\n      ~E\"\"\"\n       \n        .smooth {   transition: all 1s ease-in; font-size: 8rem; }\n       \n       \n         Color Swap Demo \n       \n      \"\"\"\n    end)\n\n    get(\"/colors\", fn _ ->\n      new_color = 3 |> :crypto.strong_rand_bytes() |> Base.encode16() |> then(&\"#{&1}\")\n      assigns = %{new_color: new_color}\n\n      ~E\"\"\"\n       \">\n      Color Swap Demo\n       \n      \"\"\"\n    end)\n  end\n```\n\nIn this scenario we are loading serving an HTML that has the htmx.js library loaded and serves the root content given by htmx/1","ref":"FrancisHtmx.html"},{"type":"macro","title":"FrancisHtmx.htmx/2","doc":"Renders htmx content by loading htmx.js and rendering binary content.","ref":"FrancisHtmx.html#htmx/2"},{"type":"macro","title":"FrancisHtmx.sigil_E/2","doc":"Provides a sigil to render EEx content similar to ~H from Phoenix.LiveView\n\nRequires a variable named \"assigns\" to exist and be set to a map.","ref":"FrancisHtmx.html#sigil_E/2"},{"type":"extras","title":"FrancisHtmx","doc":"# FrancisHtmx\n[![Hex version badge](https://img.shields.io/hexpm/v/francis_htmx.svg)](https://hex.pm/packages/francis_htmx)\n[![License badge](https://img.shields.io/hexpm/l/repo_example.svg)](https://github.com/filipecabaco/francis_htmx/blob/master/LICENSE.md)\n[![Elixir CI](https://github.com/filipecabaco/francis_htmx/actions/workflows/elixir.yaml/badge.svg)](https://github.com/filipecabaco/francis_htmx/actions/workflows/elixir.yaml)\n\nSimple helper function to add a new htmx macro that can be used by Francis to provide a simple HTMX server.\n\nIt also uses ~E that is implemented similarly to ~H sigil from Phoenix Liveview to load information into templates.","ref":"readme.html"},{"type":"extras","title":"Installation - FrancisHtmx","doc":"If available in Hex, the package can be installed by adding francis to your list of dependencies in mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:francis_htmx, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - FrancisHtmx","doc":"```elixir\ndefmodule Example do\n  use Francis\n  import FrancisHtmx\n\n  htmx(fn _conn ->\n    assigns = %{}\n    ~E\"\"\"\n     \n      .smooth {   transition: all 1s ease-in; font-size: 8rem; }\n     \n     \n       Color Swap Demo \n     \n    \"\"\"\n  end)\n\n  get(\"/colors\", fn _ ->\n    new_color = 3 |> :crypto.strong_rand_bytes() |> Base.encode16() |> then(&\"##{&1}\")\n    assigns = %{new_color: new_color}\n\n    ~E\"\"\"\n     \">\n    Color Swap Demo\n     \n    \"\"\"\n  end)\nend\n```","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}